@@ -635,13 +635,13 @@ class meta:
         return peptide_meta, protein_meta
 
 class query:
-    def __init__(self, net_data, posnet_data, negnet_data, protein_meta_data, min_interaction_confidence, interaction_confidence_bins, interaction_confidence_quantile, decoy_oversample, decoy_subsample, decoy_exclude):
+    def __init__(self, net_data, posnet_data, negnet_data, protein_meta_data, min_interaction_confidence, interaction_confidence_bins, interaction_confidence_quantile, decoy_oversample, decoy_subsample): # decoy_exclude
         self.min_interaction_confidence = min_interaction_confidence
         self.interaction_confidence_bins = interaction_confidence_bins
         self.interaction_confidence_quantile = interaction_confidence_quantile
         self.decoy_oversample = decoy_oversample
         self.decoy_subsample = decoy_subsample
-        self.decoy_exclude = decoy_exclude
+        # self.decoy_exclude = decoy_exclude
         self.df = self.generate_query(net_data, posnet_data, negnet_data, protein_meta_data)
  
     def generate_query(self, net_data, posnet_data, negnet_data, protein_meta_data):
@@ -686,13 +686,16 @@ class query:
             decoy_queries = pd.merge(negnet_data.to_df(), protein_meta_data, left_on='prey_id', right_on='protein_id', how='inner')
             decoy_queries['learning'] = False
 
-        # Exclude conflicting data from decoys (present in both targets and decoys)
-        if self.decoy_exclude:
-            decoy_queries = pd.merge(decoy_queries, queries[['bait_id','prey_id','decoy']], on=['bait_id','prey_id'], how='left')
-            decoy_queries = decoy_queries.fillna(True)
-            decoy_queries = decoy_queries[decoy_queries['decoy'] == True]
-        else:
-            decoy_queries['decoy'] = True
+        # Deprecated logic
+        # # Exclude conflicting data from decoys (present in both targets and decoys)
+        # if self.decoy_exclude:
+        #     decoy_queries = pd.merge(decoy_queries, queries[['bait_id','prey_id','decoy']], on=['bait_id','prey_id'], how='left')
+        #     decoy_queries = decoy_queries.fillna(True)
+        #     decoy_queries = decoy_queries[decoy_queries['decoy'] == True]
+        # else:
+        #     decoy_queries['decoy'] = True
+        
+        decoy_queries['decoy'] = True
 
         # Filter for minimum interaction confidence
         queries = queries[queries['interaction_confidence'] >= self.min_interaction_confidence]
